import August from 'august-yale';
import type { AugustPlatformConfig, device, devicesConfig } from './settings.js';
import type { API, DynamicPlatformPlugin, Logging, PlatformAccessory } from 'homebridge';
/**
 * HomebridgePlatform
 * This class is the main constructor for your plugin, this is where you should
 * parse the user config and discover/register accessories with Homebridge.
 */
export declare class AugustPlatform implements DynamicPlatformPlugin {
    accessories: PlatformAccessory[];
    readonly api: API;
    readonly log: Logging;
    config: AugustPlatformConfig;
    platformConfig: AugustPlatformConfig['options'];
    platformLogging: AugustPlatformConfig['logging'];
    registeringDevice: boolean;
    debugMode: boolean;
    version: string;
    augustConfig: August;
    constructor(log: Logging, config: AugustPlatformConfig, api: API);
    /**
     * This function is invoked when homebridge restores cached accessories from disk at startup.
     * It should be used to setup event handlers for characteristics and update respective values.
     */
    configureAccessory(accessory: PlatformAccessory): void;
    /**
     * Verify the config passed to the plugin is valid
     */
    verifyConfig(): void;
    /**
     * This method looks to see if session is already Validate, if not then sends a validateCode and saves the installId.
     * After validateCode is saved to the config user must restart homebridge
     * this process then looks to see if session is already validated and if the validateCode in config;
     * if isValidated is false then it will validate iwth the validateCode and save isValidated as true in the config.json file
     * will also make the validateCode undefined
     * @param this.config.credentials.installId
     * @param this.config.credentials.isValidated
     * @param this.config.credentials.validateCode
     */
    validated(): Promise<void>;
    augustCredentials(): Promise<void>;
    pluginConfig(): Promise<{
        pluginConfig: any;
        currentConfig: any;
    }>;
    /**
     * This method is used to discover the your location and devices.
     */
    discoverDevices(): Promise<void>;
    private Lock;
    private registerDevice;
    externalOrPlatform(device: device & devicesConfig, accessory: PlatformAccessory): Promise<void>;
    externalAccessory(accessory: PlatformAccessory): Promise<void>;
    unregisterPlatformAccessories(existingAccessory: PlatformAccessory, device: device & devicesConfig): void;
    getVersion(): Promise<void>;
    getPlatformConfigSettings(): Promise<void>;
    getPlatformLogSettings(): Promise<void>;
    /**
      * If device level logging is turned on, log to log.warn
      * Otherwise send debug logs to log.debug
      */
    infoLog(...log: any[]): void;
    successLog(...log: any[]): void;
    debugSuccessLog(...log: any[]): void;
    warnLog(...log: any[]): void;
    debugWarnLog(...log: any[]): void;
    errorLog(...log: any[]): void;
    debugErrorLog(...log: any[]): void;
    debugLog(...log: any[]): void;
    enablingPlatformLogging(): boolean;
}
//# sourceMappingURL=platform.d.ts.map